@@ -44,12 +44,14 @@ define('MAIN_MENU_RERUN_WIZARD_BTN', "Re-run Wizard");
 define('MAIN_MENU_UPLOAD_TEMPLATE_BTN', "Upload Template");
 define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN', "Manage Users &amp; Site Options");
 define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT', "Manage Users and Site Options");
+define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Manage My Account");
 define('MAIN_MENU_NEW_SESSION_BTN', "NEW SESSION");
 define('MAIN_MENU_LOGOUT_BTN', "LOGOUT");
 // Console Text:
 define('MAIN_MENU_HEADER_DIVIDER', "BREEZE WEBSITE BUILDING MODULE");
 // JavaScript Constants
 define('MAIN_MENU_TIMEOUT_ERR', "Your session has timed out.  Do you want to log back in?");
+define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Your password has been updated with the temporary password.  It is recommended that you change your password to somethitng easier to type and remember, and then store your new password in a safe location. Do you want to change your password now?");
 
 ///////////////////////// Login /////////////////////////
 // Buttons:
@@ -313,6 +315,8 @@ define('EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG', "You have new item which has n
 // Buttons:
 define('MANAGE_MENUS_HEADING', "Manage Menu Assignments");
 define('MANAGE_MENUS_CREATE_NEW_MENU_BTN', "Create New Menu");
+define('MANAGE_MENUS_COPY_MENU_BTN', "Copy Menu");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Copy Desktop Menu Items to Mobile");
 // Console Text:
 define('MANAGE_MENUS_ADD_MENU', "Add Menu");
 define('MANAGE_MENUS_MENU_TYPE', "Menu Type");
@@ -322,8 +326,7 @@ define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Select the menu you want to delete
 define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Update Menu Description");
 define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Select the menu you want to revise");
 define('MANAGE_MENUS_NEW_DESCRIPTION', "New Description");
-define('MANAGE_MENUS_CHANGE_MENU_TYPE', "Change Menu Type");
-define('MANAGE_MENUS_NEW_MENU_TYPE', "New Menu Type");
+define('MANAGE_MENUS_CREATE_NEW', "New Menu");
 // Popup Messages:
 define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "You will need to re-assign this menu to the border area to complete the conversion.");
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Are you sure you want to delete the");
@@ -332,6 +335,10 @@ define('MANAGE_MENUS_MENU_ASSIGNED_1_MSG', "The");
 define('MANAGE_MENUS_MENU_ASSIGNED_2_MSG', "menu");
 define('MANAGE_MENUS_MENU_ASSIGNED_3_MSG', "has been assigned to the");
 define('MANAGE_MENUS_MENU_ASSIGNED_4_MSG', "border area.");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Are you sure you want to copy the");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "menu to the");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "menu?");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "menu items to the");
 
 ///////////////////////// Edit CSS Menu Parameters /////////////////////////
 // Buttons:
@@ -458,6 +465,7 @@ define('EDIT_CSS_ADD_DELETE_CUSTOM_STYLE_BTN', "Add/Delete Custom Style");
 define('EDIT_CSS_LOAD_BROWSER_RESET_CSS_BTN', "Load Browser Reset CSS");
 define('EDIT_CSS_SETUP_CENTERED_PAGES_BTN', "Setup For Centered Pages");
 define('EDIT_CSS_SETUP_STICKY_FOOTER_BTN', "Setup For Sticky Footer");
+define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Setup For Sticky Header");
 // Console Text:
 define('EDIT_CSS_CHANGE_STYLE_SHEET', "Change Style Sheet");
 define('EDIT_CSS_USE_SETTINGS_BELOW', "Use Settings Below");
@@ -556,6 +564,8 @@ define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_ALERT_MSG', "We will now load styles wi
 define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_COMPLETE_MSG', "Your site has been centered.  You may want to revise the 'body' width, the 'body' background color, and the '#wrap' backgound color to your needs.");
 define('EDIT_CSS_LOAD_STICKY_FOOTERS_ALERT_MSG', "We will now load styles with settings that will cause the footer of your web pages to 'stick' to the bottom of your browser window.");
 define('EDIT_CSS_LOAD_STICKY_FOOTERS_COMPLETE_MSG', "Your footer will now stick to the bottom of the browser window.  You may also want to revise the 'footer' height and the background color to your needs. Be sure to set the footer's margin top to the same but negative of the footer's height.");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "We will now load styles with settings that will cause the header of your web pages to 'stick' to the top of your browser window.");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Your header will now stick to the top of the browser window.");
 define('EDIT_CSS_BORDER_REQUIREMENTS_MSG', "It appears that you are trying to setup a border, but you don't have any sides selected.  You must check at least one of the boxes labeled <b>Top</b>, <b>Bottom</b>, <b>Left</b> or <b>Right</b>.");
 define('EDIT_CSS_BORDER_REQUIREMENTS_STYLE_ADENDUM_MSG', "You must specify a <b>border style</b> in order for a border to display.");
 define('EDIT_CSS_LETTER_SPACING_REQUIREMENTS_MSG', "You have selected <b>Normal</b>, <b>Initial</b> or <b>Inherit</b> for your letter spacing, yet you have a number set for letter spacing. Note that the number you have selected will be ignored.  If you want to set a letter spacing, choose <b>px</b> instead.");
@@ -880,6 +890,7 @@ define('UPLOAD_TEMPLATE_COPYING_CSS_MSG', "Copying css...");
 define('UPLOAD_TEMPLATE_COPYING_MEDIA_MSG', "Copying media...");
 define('UPLOAD_TEMPLATE_COPYING_FLASH_MSG', "Copying flash...");
 define('UPLOAD_TEMPLATE_COPYING_SCRIPTS_MSG', "Copying scripts...");
+define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Copying fonts...");
 define('UPLOAD_TEMPLATE_COPYING_XML_MSG', "Copying XML...");
 define('UPLOAD_TEMPLATE_UNABLE_TO_OPEN_DOC_ROOT_ERR', "Unable to open document root.");
 define('UPLOAD_TEMPLATE_COULD_NOT_RENAME_ERR', "Could not rename");
@@ -930,6 +941,8 @@ define('MANAGE_USERS_HEADING', "Manage Users");
 // Console Text:
 define('MANAGE_USERS_SSL_NOT_PRESENT_WARNING', "<b>WARNING:</b> You are viewing this console with an unencrypted connection.  If you are adding users or changing passwords it is recommended that you use an encrypted connection.  To switch to an encrypted connection, click");
 define('MANAGE_USERS_INVALID_CERTIFICATE_NOTE', "Note: The SSL certificate may not be valid.  If this is the case, just accept the certificate anyway and continue to the encrypted connection.  Also, some servers do not have SSL certificates installed, so it might not be possible to view this console encrypted.  If clicking on the link does not work just click the back button.");
+define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Change My Password");
+define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Modify My Account");
 // Popup Messages:
 define('MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG', "Are your sure you want to delete the user");
 define('MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG', "?");
@@ -1360,6 +1373,8 @@ define('DAYS_WORD', "days");
 define('OR_WORD', "or");
 define('OR_CAP_WORD', "OR");
 define('TO_WORD', "to");
+define('TO_1ST_CAP_WORD', "To");
+define('FROM_WORD', "From");
 define('CLICK_WORD', "Click");
 define('PAGE_WORD', "page");
 define('PAGE_1ST_CAP_WORD', "Page");
@@ -1437,6 +1452,7 @@ define('ANGLE_WORD', "Angle");
 define('DEGREES_WORD', "Degrees");
 define('HOVER_WORD', "Hover");
 define('DOWN_WORD', "Down");
+define('STICKY_WORD', "Sticky");
 
 define('QUERY_READY_TO_SEND', "Query ready to send...");
 define('QUERY_SENT', "Query sent");
