@@ -309,8 +309,6 @@ define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Valige menüü, mida soovite kustu
 define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Uuenda Menüü Kirjeldus");
 define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Valige menüü, mida soovite vaadata");
 define('MANAGE_MENUS_NEW_DESCRIPTION', "uus kirjeldus");
-define('MANAGE_MENUS_CHANGE_MENU_TYPE', "Muuda menüü Type");
-define('MANAGE_MENUS_NEW_MENU_TYPE', "Uus menüü Type");
 // Popup Messages:
 define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "Sa pead uuesti määrata selle menüü piirialal ülemineku lõpuleviimisel.");
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
@@ -1498,4 +1496,22 @@ define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Baas Z-Index");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "Selles kategoorias pole ühtegi plugina");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Kliki");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "selle kategooria plugina leidmiseks.");
+define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Minu konto haldamine");
+define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Teie parooli on ajakohastatud ajutise parooliga. Soovitatav on muuta oma salasõna, et somethitngit hõlpsamini sisestada ja meelde jätta, ning seejärel salvestage uus parool turvalises kohas. Kas soovite oma parooli kohe muuta?");
+define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Muuda minu parooli");
+define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Muuda minu kontot");
+define('STICKY_WORD', "Kleepuv");
+define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Kleepuva päise seadistamine");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nüüd laadime stiile sätted, mis paneb teie veebilehtede päise oma brauseriakna ülaosas kinni.");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Teie päis jääb nüüd brauseriakna ülaossa.");
+define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Fontide kopeerimine ...");
+define('MANAGE_MENUS_COPY_MENU_BTN', "Kopeeri menüü");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Kopeeri töölauamenüü üksused mobiilseadmesse");
+define('MANAGE_MENUS_CREATE_NEW', "Uus menüü");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Kas olete kindel, et soovite selle kopeerida");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "menüüst");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "menüü?");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "menüüelemendid");
+define('TO_1ST_CAP_WORD', "Et");
+define('FROM_WORD', "Alates");
 ?>
\ No newline at end of file
