@@ -309,8 +309,6 @@ define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Chwazi meni an ou vle efase");
 define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Mizajou Menu Deskripsyon");
 define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Chwazi meni an ou vle revize");
 define('MANAGE_MENUS_NEW_DESCRIPTION', "nouvo Deskripsyon");
-define('MANAGE_MENUS_CHANGE_MENU_TYPE', "Kalite Chanje Menu");
-define('MANAGE_MENUS_NEW_MENU_TYPE', "Nouvo Kalite Menu");
 // Popup Messages:
 define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "Ou ap bezwen re-bay meni sa a nan zòn nan fwontyè ranpli konvèsyon an.");
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Èske ou sèten ou vle efase nan");
@@ -1498,4 +1496,22 @@ define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Sèvi Z-Index");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "Pa gen okenn grefon anba kategori a");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Klike sou");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "jwenn yon Plugin nan kategori sa a.");
+define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Jere kont mwen");
+define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Modpas ou te mete ajou ak modpas tanporè a. Li rekòmande ke ou chanje modpas ou a somethitng pi fasil yo tape ak sonje, ak Lè sa a, magazen nouvo modpas ou nan yon kote ki an sekirite. Ou vle chanje modpas ou an kounye a?");
+define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Chanje Modpas mwen");
+define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Modifye kont mwen an");
+define('STICKY_WORD', "Kolye");
+define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Enstalasyon Pou Heady Sticky");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nou pral kounye a chaje estil ak anviwònman ki pral lakòz header nan paj wèb ou nan &#39;bwa&#39; nan tèt la nan fenèt navigatè ou a.");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Lento ou pral kounye a bwa nan tèt la nan fenèt navigatè a.");
+define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Kopi polis ...");
+define('MANAGE_MENUS_COPY_MENU_BTN', "Kopi meni an");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Kopi Atik Menu Desktop nan mobil");
+define('MANAGE_MENUS_CREATE_NEW', "New Menu");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Èske ou sèten ou vle kopye a");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "meni nan la");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "meni?");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "meni atik nan la");
+define('TO_1ST_CAP_WORD', "Pou");
+define('FROM_WORD', "Soti nan");
 ?>
\ No newline at end of file
