@@ -309,8 +309,6 @@ define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Lego delere vis menu");
 define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Update Menu Description");
 define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Lego retractari vis menu");
 define('MANAGE_MENUS_NEW_DESCRIPTION', "Description New");
-define('MANAGE_MENUS_CHANGE_MENU_TYPE', "Type Menu");
-define('MANAGE_MENUS_NEW_MENU_TYPE', "Type Menu");
 // Popup Messages:
 define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "Vos mos postulo iterum ad terminum regionem assignare menu perficere conversionem.");
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Es vos certus vos volo ut delete");
@@ -1498,4 +1496,22 @@ define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Basis margin-right");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "Illic es plugins nullum genus sub");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Click");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "locate, quod est genus a plugin in.");
+define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Curo My Account");
+define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Vestri password in tempus est updated cum password. Suadetur ut mutare vestri password ut somethitng est facillimus ut typus et recordabor contrahas et quasi reponas in vestri password tutum locum novam. Tu autem vis ad mutare vestri password?");
+define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Mutata meum Password");
+define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Mutari My Account");
+define('STICKY_WORD', "Pellentesque");
+define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Pellentesque setup nam Header");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nos mos iam load de causa dicendi generibus et occasus erit super caput tuum paginas telae, quae est &#39;lignum&#39; in vestri pasco fenestra est summitatem.");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Et nunc inhaero vestri caput capitis in vertice ad pasco fenestra.");
+define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Effingo ... fonts");
+define('MANAGE_MENUS_COPY_MENU_BTN', "exemplum Menu");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Menu Item exemplum Desktop ut mobile");
+define('MANAGE_MENUS_CREATE_NEW', "novum Menu");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Esne certus vos volo ut effingo quod");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "in menu");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "menu?");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "in menu items");
+define('TO_1ST_CAP_WORD', "Ad");
+define('FROM_WORD', "Ex");
 ?>
\ No newline at end of file
