@@ -309,8 +309,6 @@ define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "选择要删除的菜单");
 define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "更新菜单说明");
 define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "选择您要修改菜单");
 define('MANAGE_MENUS_NEW_DESCRIPTION', "新的说明");
-define('MANAGE_MENUS_CHANGE_MENU_TYPE', "更改菜单类型");
-define('MANAGE_MENUS_NEW_MENU_TYPE', "新菜单类型");
 // Popup Messages:
 define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "您需要将这个菜单重新分配到边境地区完成转换。");
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "您确定要删除");
@@ -1498,4 +1496,22 @@ define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "基数指数");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "该类别下没有插件");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "点击");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "在该类别中找到一个插件。");
+define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "管理我的帐户");
+define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "您的密码已更新为临时密码。建议您将密码更改为更易于输入和记忆的密码，然后将新密码存储在安全的位置。你想现在改变你的密码吗？");
+define('MANAGE_USERS_CHANGE_MY_PASSWORD', "修改我的密码");
+define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "修改我的帐户");
+define('STICKY_WORD', "黏");
+define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "粘滞标题的设置");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "现在，我们将使用设置加载样式，这些设置会导致网页标题“粘”到浏览器窗口的顶部。");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "您的标题现在将粘贴到浏览器窗口的顶部。");
+define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "复制字体...");
+define('MANAGE_MENUS_COPY_MENU_BTN', "复制菜单");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "将桌面菜单项复制到手机");
+define('MANAGE_MENUS_CREATE_NEW', "新菜单");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "你确定你想复制这个");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "菜单");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "菜单？");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "菜单项");
+define('TO_1ST_CAP_WORD', "至");
+define('FROM_WORD', "从");
 ?>
\ No newline at end of file
