@@ -515,230 +515,115 @@ define('EDIT_FILE_SELECT_SELECT_FILE', "選擇文件");
 
 define('EDIT_FILE_SELECT_NO_FOLDER_ERR', "錯誤：沒有指定的文件夾");
 
-
-
 ///////////////////////// Edit Menu Items /////////////////////////
-
 // Buttons:
-
 define('EDIT_MENU_ITEMS_HEADING', "編輯菜單");
-
 define('EDIT_MENU_ITEMS_UPDATE_ALL_BTN', "全部更新");
-
 // Console Text:
-
 define('EDIT_MENU_ITEMS_SELECT_MENU', "選擇一個菜單項添加到");
-
 define('EDIT_MENU_ITEMS_ITEM_TEXT', "資料文本");
-
 define('EDIT_MENU_ITEMS_NESTING_LEVEL', "嵌套級別");
-
 define('EDIT_MENU_ITEMS_URL', "網址");
-
 define('EDIT_MENU_ITEMS_TARGET_WINDOW', "目標窗口");
-
 define('EDIT_MENU_ITEMS_TOP_LEVEL', "頂層");
-
 define('EDIT_MENU_ITEMS_1ST_SUB_LEVEL', "1分級別");
-
 define('EDIT_MENU_ITEMS_2ND_SUB_LEVEL', "第二子級");
-
 define('EDIT_MENU_ITEMS_3RD_SUB_LEVEL', "3分等級");
-
 define('EDIT_MENU_ITEMS_4TH_SUB_LEVEL', "4分等級");
-
 define('EDIT_MENU_ITEMS_5TH_SUB_LEVEL', "5分級別");
-
 define('EDIT_MENU_ITEMS_SELECT_MENU_MSG', "請選擇一個菜單，編輯菜單項。");
-
 // Popup Messages:
-
 define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_1_MSG', "您確定要刪除");
-
 define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_2_MSG', "菜單項？");
-
 define('EDIT_MENU_ITEMS_STARTING_DELETE_MSG', "開始刪除...");
-
 define('EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG', "查找菜單項...");
-
 define('EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG', "沒有找到記錄。無法刪除的菜單項。");
-
 define('EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG', "菜單項刪除");
-
 define('EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG', "刪除的菜單項...");
-
 define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG', "沒有找到記錄。無法更新菜單項。");
-
 define('EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG', "菜單項更新");
-
 define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG', "更新菜單項...");
-
 define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG', "沒有找到記錄。無法更新菜單項。");
-
 define('EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG', "菜單項更新");
-
 define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG', "更新菜單項...");
-
 define('EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG', "檢索菜單項...");
-
 define('EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG', "您的更改尚未保存。你想返回到主菜單前保存更改？");
 
-
-
 ///////////////////////// Manage Menu Assignments /////////////////////////
-
 // Buttons:
-
 define('MANAGE_MENUS_HEADING', "管理菜單分配");
-
 define('MANAGE_MENUS_CREATE_NEW_MENU_BTN', "創建新菜單");
-
 // Console Text:
-
 define('MANAGE_MENUS_ADD_MENU', "添加菜單");
-
 define('MANAGE_MENUS_MENU_TYPE', "菜單類型");
-
 define('MANAGE_MENUS_ASSIGN_MENU_TO_BORDER', "指定菜單邊區");
-
 define('MANAGE_MENUS_DELETE_MENU', "刪除菜單");
-
 define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "選擇要刪除的菜單");
-
 define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "更新菜單說明");
-
 define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "選擇您要修改菜單");
-
 define('MANAGE_MENUS_NEW_DESCRIPTION', "新的說明");
-
-define('MANAGE_MENUS_CHANGE_MENU_TYPE', "更改菜單類型");
-
-define('MANAGE_MENUS_NEW_MENU_TYPE', "新菜單類型");
-
 // Popup Messages:
-
 define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "您需要將這個菜單重新分配到邊境地區完成轉換。");
-
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "您確定要刪除");
-
 define('MANAGE_MENUS_DELETE_MENU_CONFIRM_2_MSG', "菜單？");
-
 define('MANAGE_MENUS_MENU_ASSIGNED_1_MSG', "該");
-
 define('MANAGE_MENUS_MENU_ASSIGNED_2_MSG', "菜單");
-
 define('MANAGE_MENUS_MENU_ASSIGNED_3_MSG', "已被分配給該");
-
 define('MANAGE_MENUS_MENU_ASSIGNED_4_MSG', "邊區。");
 
-
-
 ///////////////////////// Edit CSS Menu Parameters /////////////////////////
-
 // Buttons:
-
 define('EDIT_CSS_MENU_PARAMETERS_HEADING', "CSS菜單參數快速設置編輯器");
-
 // Console Text:
-
 define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU', "選擇設置菜單");
-
 define('EDIT_CSS_MENU_PARAMETERS_LAYOUT_ORIGIN', "菜單佈局和Origin（從頁面的左上角）");
-
 define('EDIT_CSS_MENU_PARAMETERS_LOCATION', "菜單位置");
-
 define('EDIT_CSS_MENU_PARAMETERS_FIXED_WIDTH', "（固定寬度）");
-
 define('EDIT_CSS_MENU_PARAMETERS_VARIABLE_WIDTH', "（可變寬度）");
-
 define('EDIT_CSS_MENU_PARAMETERS_MENU_WIDTH', "菜單的寬度");
-
 define('EDIT_CSS_MENU_PARAMETERS_SPECIAL_NOTE', "注：選擇上述任何位置不分配菜單，這些領域之一。它只是強調了這種形式與所選區域的典型設置。");
-
 define('EDIT_CSS_MENU_PARAMETERS_ITEM_SIZE_PADDING', "菜單項大小和填充");
-
 define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_POSITIONING', "子菜單定位");
-
 define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_TOP', "從頂部偏移");
-
 define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_LEFT', "從左偏移");
-
 define('EDIT_CSS_MENU_PARAMETERS_COLLAPSE_EXPAND', "折疊和展開");
-
 define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_SIZE_PADDING', "子菜單項目大小和填充");
-
 define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU_MSG', "請選擇設置菜單。");
 
-
-
 ///////////////////////// Edit CSS Menu Styles /////////////////////////
-
 // Buttons:
-
 define('EDIT_CSS_MENU_STYLES_HEADING', "CSS菜單樣式快速設置編輯器");
-
 // Console Text:
-
 define('EDIT_CSS_MENU_STYLES_SELECT_MENU', "選擇菜單樣式");
-
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_FONT', "頂級字體");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_FONT', "分1級字體");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_FONT', "分2級字體");
-
 define('EDIT_CSS_MENU_STYLES_COLORS_BACKGROUND', "顏色和背景");
-
 define('EDIT_CSS_MENU_STYLES_NORMAL_MOUSE_OUT', "正常（鼠標移出）");
-
 define('EDIT_CSS_MENU_STYLES_HOVER_MOUSE_OVER', "哈弗（鼠標懸停）");
-
 define('EDIT_CSS_MENU_STYLES_ACTIVE_MOUSE_CLICK', "活動（鼠標點擊）");
-
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_TEXT_COLOR', "頂級文本顏色");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_TEXT_COLOR', "分1級文字顏色");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "分2級文本顏色");
-
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "頂級背景顏色");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "分等級背景顏色");
-
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "最頂層的方塊邊框顏色");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "分級別阻止邊框顏色");
-
 define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "頂層項目邊框顏色");
-
 define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "分層次的項目邊框顏色");
-
 define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "ŧ <br> Ø <br> p");
-
 define('EDIT_CSS_MENU_STYLES_BOTTOM_BORDER_VERTICAL', "乙<br> Ø <br> ŧ <br> ŧ <br> Ø <br>米");
-
 define('EDIT_CSS_MENU_STYLES_LEFT_BORDER_VERTICAL', "大號<br> Ë <br> F <br> ŧ");
-
 define('EDIT_CSS_MENU_STYLES_RIGHT_BORDER_VERTICAL', "-  [R <br>一世<br> G <br> H <br> ŧ");
-
 define('EDIT_CSS_MENU_STYLES_UNDERLINE_NOTE', "鏈路下劃線將被迫關閉，除非下劃線被檢查");
-
 define('EDIT_CSS_MENU_STYLES_SAME_AS_TOP_LEVEL_NOTE', "（同頂層）");
-
 define('EDIT_CSS_MENU_STYLES_SAME_AS_NORMAL_NOTE', "（同正常）");
-
 define('EDIT_CSS_MENU_STYLES_SELECT_MENU_MSG', "請選擇一個風格的菜單。");
-
 // Popup Messages:
-
 define('EDIT_CSS_MENU_STYLES_LETTER_SPACING_MSG', "您選擇<b>正常</b> ， <b>初步</b>或<b>繼承</b>你的來信間距，但你有字母間距數設置。請注意，您選擇的電話號碼將被忽略。如果你想設置一個字母間距，選擇<b>像素</b>來代替。");
-
 define('EDIT_CSS_MENU_STYLES_SAVE_SUCCESS_MSG', "你的菜單樣式已保存。");
-
 define('EDIT_CSS_MENU_STYLES_SAVE_FAIL_ERR', "有一個錯誤保存您的菜單樣式。");
 
-
-
 ///////////////////////// Edit JS Menu Parameters /////////////////////////
 
 // Buttons:
@@ -2876,4 +2761,22 @@ define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "基數指數");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "該類別下沒有插件");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "點擊");
 define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "在該類別中找到一個插件。");
+define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "管理我的帳戶");
+define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "您的密碼已更新為臨時密碼。建議您將密碼更改為更易於輸入和記憶的密碼，然後將新密碼存儲在安全的位置。你想現在改變你的密碼嗎？");
+define('MANAGE_USERS_CHANGE_MY_PASSWORD', "修改我的密碼");
+define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "修改我的帳戶");
+define('STICKY_WORD', "黏");
+define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "粘滯標題的設置");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "現在，我們將使用設置加載樣式，這些設置會導致網頁標題“粘”到瀏覽器窗口的頂部。");
+define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "您的標題現在將粘貼到瀏覽器窗口的頂部。");
+define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "複製字體...");
+define('MANAGE_MENUS_COPY_MENU_BTN', "複製菜單");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "將桌面菜單項複製到手機");
+define('MANAGE_MENUS_CREATE_NEW', "新菜單");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "你確定你想複製這個");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "菜單");
+define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "菜單？");
+define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "菜單項");
+define('TO_1ST_CAP_WORD', "至");
+define('FROM_WORD', "從");
 ?>
\ No newline at end of file
